/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GetNotificationSettingsCommand.as 4917 2009-08-14 12:35:59Z radua $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.notification.command
{
import com.adobe.cairngorm.commands.ICommand;
import com.adobe.cairngorm.control.CairngormEvent;
import com.adobe.cairngorm.control.CairngormEventDispatcher;

import mx.controls.Alert;
import mx.rpc.IResponder;
import mx.rpc.events.FaultEvent;
import mx.rpc.events.ResultEvent;

import org.ow2.jasmine.monitoring.eos.notification.business.*;
import org.ow2.jasmine.monitoring.eos.notification.model.NotificationModelLocator;
import org.ow2.jasmine.monitoring.eos.notification.vo.*;
import org.ow2.jasmine.monitoring.eos.notification.event.*;

/**
 * @author radua
 */
/**
  * The command class from the cairngorm model.
  * It gets all the notifications from the database,
  * it puts them in the model and it raises an alert
  * when something turns out wrong and the notifications
  * cannot be retrieved.
  */
public class GetNotificationSettingsCommand implements ICommand, IResponder
{
    /**
     * Retrieve the delegate and use it to get the notifs.
     */
    public function execute(event:CairngormEvent):void
    {
        var delegate:IGetNotificationSettingsDelegate = NotificationModelLocator.getInstance().getGetNotificationSettingsDelegate();
        delegate.responder = this;
        delegate.getActions();
    }

    /**
     * Push the notifs into the model.
     */

    public function result(data:Object):void
    {
        var model:NotificationModelLocator = NotificationModelLocator.getInstance();

        //var result:ArrayCollection = (data as ResultEvent).result as ArrayCollection;
        //model.actions = result;
        var result:NotificationBoardSettingsVO = (data as ResultEvent).result as NotificationBoardSettingsVO;
        model.actions = result.actionsList;
        model.columns = result.columnsList;
        sentSettings();



    }

    /**
     * Raise an alert when something is wrong.
     */
    public function fault(info:Object):void
    {
        var faultEvent:FaultEvent = FaultEvent (info);
        Alert.show( "Error during the attempt to get notifs from the database : Unhandled error","Error" );
    }

    /**
     * This function sends an event after the model received the Notification Board settings from the
     * server side (after parsing the xml configuration file).
     */
    public function sentSettings():void{
        var sentEvent: SentSettingsEvent = new SentSettingsEvent(SentSettingsEvent.SENT_SETTINGS+NotificationModelLocator.getInstance().componentID);
        CairngormEventDispatcher.getInstance().dispatchEvent(sentEvent);
    }

}
}
